Coverage for src/typedal/types.py: 100%

1"""

2 Stuff to make mypy happy.

3"""

4

5 from pydal.objects import Expression as _Expression

6 from pydal.objects import Query as _Query

7

8

9 class Query(_Query): # type: ignore

10 """

11 Pydal Query object.

12

13 Makes mypy happy.

14 """

15

16

17 class Expression(_Expression): # type: ignore

18 """

19 Pydal Expression object.

20

21 Make mypy happy.

22 """

23

24

25 class _Types:

26 """

27 Internal type storage for stuff that mypy otherwise won't understand.

28 """

29

30 NONETYPE = type(None)